==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/AttackProtectionAuthenticatorSettings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AttackProtectionAuthenticatorSettings
 */
@JsonPropertyOrder({ AttackProtectionAuthenticatorSettings.JSON_PROPERTY_VERIFY_KNOWLEDGE_SECOND_WHEN2FA_REQUIRED })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class AttackProtectionAuthenticatorSettings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_VERIFY_KNOWLEDGE_SECOND_WHEN2FA_REQUIRED = "verifyKnowledgeSecondWhen2faRequired";
    private Boolean verifyKnowledgeSecondWhen2faRequired = false;

    public AttackProtectionAuthenticatorSettings() {
    }

    public AttackProtectionAuthenticatorSettings verifyKnowledgeSecondWhen2faRequired(
            Boolean verifyKnowledgeSecondWhen2faRequired) {

        this.verifyKnowledgeSecondWhen2faRequired = verifyKnowledgeSecondWhen2faRequired;
        return this;
    }

    /**
     * If true, requires users to verify a possession factor before verifying a knowledge factor when the assurance
     * requires two-factor authentication (2FA).
     *
     * @return verifyKnowledgeSecondWhen2faRequired
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "If true, requires users to verify a possession factor before verifying a knowledge factor when the assurance requires two-factor authentication (2FA).")
    @JsonProperty(JSON_PROPERTY_VERIFY_KNOWLEDGE_SECOND_WHEN2FA_REQUIRED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getVerifyKnowledgeSecondWhen2faRequired() {
        return verifyKnowledgeSecondWhen2faRequired;
    }

    @JsonProperty(JSON_PROPERTY_VERIFY_KNOWLEDGE_SECOND_WHEN2FA_REQUIRED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVerifyKnowledgeSecondWhen2faRequired(Boolean verifyKnowledgeSecondWhen2faRequired) {
        this.verifyKnowledgeSecondWhen2faRequired = verifyKnowledgeSecondWhen2faRequired;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AttackProtectionAuthenticatorSettings attackProtectionAuthenticatorSettings = (AttackProtectionAuthenticatorSettings) o;
        return Objects.equals(this.verifyKnowledgeSecondWhen2faRequired,
                attackProtectionAuthenticatorSettings.verifyKnowledgeSecondWhen2faRequired);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(verifyKnowledgeSecondWhen2faRequired);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AttackProtectionAuthenticatorSettings {\n");
        sb.append("    verifyKnowledgeSecondWhen2faRequired: ")
                .append(toIndentedString(verifyKnowledgeSecondWhen2faRequired)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/AttackProtectionAuthenticatorSettings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AttackProtectionAuthenticatorSettings
 */
@JsonPropertyOrder({ AttackProtectionAuthenticatorSettings.JSON_PROPERTY_VERIFY_KNOWLEDGE_SECOND_WHEN2FA_REQUIRED })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class AttackProtectionAuthenticatorSettings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_VERIFY_KNOWLEDGE_SECOND_WHEN2FA_REQUIRED = "verifyKnowledgeSecondWhen2faRequired";
    private Boolean verifyKnowledgeSecondWhen2faRequired = false;

    public AttackProtectionAuthenticatorSettings() {
    }

    public AttackProtectionAuthenticatorSettings verifyKnowledgeSecondWhen2faRequired(
            Boolean verifyKnowledgeSecondWhen2faRequired) {

        this.verifyKnowledgeSecondWhen2faRequired = verifyKnowledgeSecondWhen2faRequired;
        return this;
    }

    /**
     * If true, requires users to verify a possession factor before verifying a knowledge factor when the assurance
     * requires two-factor authentication (2FA).
     *
     * @return verifyKnowledgeSecondWhen2faRequired
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "If true, requires users to verify a possession factor before verifying a knowledge factor when the assurance requires two-factor authentication (2FA).")
    @JsonProperty(JSON_PROPERTY_VERIFY_KNOWLEDGE_SECOND_WHEN2FA_REQUIRED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getVerifyKnowledgeSecondWhen2faRequired() {
        return verifyKnowledgeSecondWhen2faRequired;
    }

    @JsonProperty(JSON_PROPERTY_VERIFY_KNOWLEDGE_SECOND_WHEN2FA_REQUIRED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVerifyKnowledgeSecondWhen2faRequired(Boolean verifyKnowledgeSecondWhen2faRequired) {
        this.verifyKnowledgeSecondWhen2faRequired = verifyKnowledgeSecondWhen2faRequired;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AttackProtectionAuthenticatorSettings attackProtectionAuthenticatorSettings = (AttackProtectionAuthenticatorSettings) o;
        return Objects.equals(this.verifyKnowledgeSecondWhen2faRequired,
                attackProtectionAuthenticatorSettings.verifyKnowledgeSecondWhen2faRequired);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(verifyKnowledgeSecondWhen2faRequired);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AttackProtectionAuthenticatorSettings {\n");
        sb.append("    verifyKnowledgeSecondWhen2faRequired: ")
                .append(toIndentedString(verifyKnowledgeSecondWhen2faRequired)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
